
from setuptools import setup, find_packages
import pathlib

setup(
    name='kojis',
    version='1.3',
    url= 'https://alantimes2020.blogspot.com/',
    author='Pylan64 & and the Kojis Team',
    description='Koji helps teach kids programming with Python through emojis and fun tinker tools!'
)
